@@ -1460,7 +1460,6 @@ our $gnusocial_choose_strong_password=sub {
    \__ \  _| '_/ _ \ ' \/ _` | |  _/ _` (_-<_-< V  V / _ \ '_/ _` |
    |___/\__|_| \___/_||_\__, | |_| \__,_/__/__/\_/\_/\___/_| \__,_|
                         |___/
-
 END
    use Crypt::GeneratePassword qw(word);
    my $word='';
@@ -1613,6 +1612,220 @@ END
 
 };
 
+our $gnusocial_enter_twitter_creds=sub {
+
+   my $twitter_creds_banner=<<'END';
+
+END
+   my $gnusocial_twitter_creds={
+
+      Name => 'gnusocial_twitter_creds',
+      Result => $gnusocial_setup_summary,
+      Banner => $twitter_creds_banner,
+
+   };
+   return $gnusocial_twitter_creds;
+
+};
+
+our $gnusocial_enter_values=sub {
+
+   package gnusocial_enter_values;
+   my $permanent_ip="]T[{permanent_ip}";
+   unless ($permanent_ip=~s/^.*Elastic.* (\d+\.\d+\.\d+\.\d+).*$/$1/s) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: You must use an Elastic IP for twitter bridge!";
+      sleep 5;
+      STDOUT->autoflush(0);
+      return '{permanent_ip}<';
+   }
+   my $enter_values_banner=<<'END';
+    ___     _             _____ _                 __   __    _               _
+   | __|_ _| |_ ___ _ _  |_   _| |_  ___ ___ ___  \ \ / /_ _| |_  _ ___ ___ (_)
+   | _|| ' \  _/ -_) '_|   | | | ' \/ -_|_-</ -_)  \ V / _` | | || / -_|_-<  _
+   |___|_||_\__\___|_|     |_| |_||_\___/__/\___|   \_/\__,_|_|\_,_\___/__/ (_)
+
+
+END
+   $enter_values_banner.=<<END;
+
+   Name         -->  ]I[{'gnusocial_enter_site_name',1}
+
+   Description  -->  ]I[{'gnusocial_enter_site_name',1} GNU Social
+
+   WebSite      -->  https://$permanent_ip/main/all
+
+   Callback URL -->  https://$permanent_ip/twitter/authorization
+
+END
+   my $enter_values={
+
+      Name => 'enter_values',
+      Result => 
+   $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_enter_twitter_creds,
+      Banner => $enter_values_banner,
+
+   };
+   return $enter_values;
+
+};
+
+our $gnusocial_twitter_app=sub {
+
+   my $twitter_app_banner=<<'END';
+
+     ___              _         _          _ _   _               _
+    / __|_ _ ___ __ _| |_ ___  | |___ __ _(_) |_| |_ ___ _ _    /_\  _ __ _ __
+   | (__| '_/ -_) _` |  _/ -_) |  _\ V  V / |  _|  _/ -_) '_|  / _ \| '_ \ '_ \
+    \___|_| \___\__,_|\__\___|  \__|\_/\_/|_|\__|\__\___|_|   /_/ \_\ .__/ .__/
+                                                                    |_|  |_|
+
+END
+   $twitter_app_banner.=<<END;
+   In your favorite browser, make sure you are first logged in with the twitter
+   account you intend to use for the twitter bridge. Then, navigate to this URL:
+
+   https://apps.twitter.com/app/new
+
+   You will see a page with a number of input boxes asking for very specific
+   information. Press [ENTER] and the next screen of this setup will give you
+   values to cut and paste into those input boxes.
+END
+   my $twitter_app={
+
+      Name => 'twitter_app',
+      Result => $gnusocial_enter_values,
+      Banner => $twitter_app_banner,
+
+   };
+   return $twitter_app;
+
+};
+
+our $gnusocial_no_twitter=sub {
+
+   my $no_twitter_banner=<<'END';
+     ___              _         _  _
+    / __|_ _ ___ __ _| |_ ___  | \| |_____ __ __
+   | (__| '_/ -_) _` |  _/ -_) | .` / -_) V  V /
+    \___|_| \___\__,_|\__\___| |_|\_\___|\_/\_/
+    _          _ _   _               _                      _
+   | |___ __ _(_) |_| |_ ___ _ _    /_\  __ __ ___ _  _ _ _| |_
+   |  _\ V  V / |  _|  _/ -_) '_|  / _ \/ _/ _/ _ \ || | ' \  _|
+    \__|\_/\_/|_|\__|\__\___|_|   /_/ \_\__\__\___/\_,_|_||_\__|
+
+END
+   $no_twitter_banner.=<<END;
+   If you don't have a twitter account, or wish to create a separate account
+   for use with GNU Social, you will need to create one. You can sign up for
+   a twitter account at the link below. Once you have completed that task,
+   you can continue setting up the twitter bridge by hitting [ENTER].
+
+   https://twitter.com/signup?lang=en
+
+END
+   my $new_twitter_account={
+
+      Name => 'new_twitter_account',
+      Result => $gnusocial_twitter_app,
+      Banner => $no_twitter_banner,
+
+   };
+   return $new_twitter_account;
+
+};
+
+our $gnusocial_setting_up_bridge=sub {
+
+   package gnusocial_setting_up_bridge;
+   my $setting_up_bridge_banner=<<'END';
+    ___      _   _   _             _   _        ___     _    _
+   / __| ___| |_| |_(_)_ _  __ _  | | | |_ __  | _ )_ _(_)__| |__ _ ___
+   \__ \/ -_)  _|  _| | ' \/ _` | | |_| | '_ \ | _ \ '_| / _` / _` / -_)
+   |___/\___|\__|\__|_|_||_\__, |  \___/| .__/ |___/_| |_\__,_\__, \___|
+                           |___/        |_|                   |___/
+
+END
+   $setting_up_bridge_banner.=<<END;
+   From a purely technical standpoint, FullAuto could completely automate the
+   setup of the twitter bridge, like it has every other aspect of GNU Social.
+   Unfortunately, most of the setup work needed for this option, has to take
+   place on the twitter website. Using external (to twitter's site)
+   automation to manipulate the twitter site, is a violation of twitter's
+   license agreement that everyone agrees to when they first create a twitter
+   account. This FullAuto installer however, will walk you through the process
+   of setting up the twitter bridge, and will provide all the items you will
+   need to do it successfully.
+
+END
+  
+   my $setting_up_bridge={
+
+      Name => 'setting_up_bridge',
+      Item_1 => {
+         Text => 'I have a twitter account',
+         Result => $gnusocial_setup_summary,
+      },
+      Item_2 => {
+         Text => 'I do NOT have a twitter account',
+         Result => 
+            $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_no_twitter,
+      },
+      Scroll => 1,
+      Banner => $setting_up_bridge_banner, 
+
+   }; 
+   return $setting_up_bridge;
+
+};
+
+our $gnusocial_twitter_bridge=sub {
+
+   package gnusocial_twitter_bridge;
+   my $gnusocial_twitter_banner=<<'END';
+    _          _ _   _             _        _    _         ___
+   | |___ __ _(_) |_| |_ ___ _ _  | |__ _ _(_)__| |__ _ __|__ \
+   |  _\ V  V / |  _|  _/ -_) '_| | '_ \ '_| / _` / _` / -_)/_/
+    \__|\_/\_/|_|\__|\__\___|_|   |_.__/_| |_\__,_\__, \___(_)
+                                                  |___/
+
+END
+   $gnusocial_twitter_banner.=<<END;
+   The twitter "bridge" plugin allows you to integrate your GNU Social
+   instance with twitter.  Installing it will allow your users to:
+
+   - automatically post notices to their twitter accounts
+   - automatically subscribe to other twitter users who are also using
+     your GNU Social install, if possible 
+   - import their twitter friends' tweets
+   - allow users to authenticate using twitter ('Sign in with twitter')
+
+   Install twitter bridge?
+
+END
+   my $gnusocial_twitter_bridge={ 
+
+      Name => 'gnusocial_twitter_bridge',
+      Item_1 => {
+
+         Text => 'Install twitter bridge',
+         Result => 
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_setting_up_bridge,
+
+      },
+      Item_2 => {
+
+         Text => 'DO NOT install twitter bridge',
+         Result => $gnusocial_setup_summary,
+
+      },
+      Scroll => 2,
+      Banner => $gnusocial_twitter_banner,
+   };
+   return $gnusocial_twitter_bridge; 
+
+};
+
 our $gnusocial_choose_build=sub {
 
    use JSON::XS;
@@ -1663,7 +1876,8 @@ END
 
          Text => ']C[',
          Convey => \@builds,
-         Result => $gnusocial_setup_summary
+         #Result => $gnusocial_setup_summary
+         Result => $gnusocial_twitter_bridge,
 
       },
       Scroll => $scrollnum,
@@ -1675,6 +1889,15 @@ END
 
 our $gnusocial_choose_site_profile=sub {
 
+   package gnusocial_choose_site_profile;
+   my $site_name="]I[{'gnusocial_enter_site_name',1}";
+   unless ($site_name) {
+      STDOUT->autoflush(1);
+      print "\n   ERROR: Site Name cannot be blank!";sleep 5;
+      STDOUT->autoflush(0);
+      return '<';
+   }
+
    my $gnusocial_profile_banner=<<'END';
 
      ___ _                       ___ _ _         ___          __ _ _
@@ -1698,7 +1921,8 @@ END
                       'Private (no federation)'
                    ],
          #Result => $gnusocial_setup_summary
-         Result => $gnusocial_choose_build,
+         Result =>
+      $Net::FullAuto::ISets::Amazon::GNUSocial_is::gnusocial_choose_build,
 
       },
       Scroll => 2,
@@ -1887,8 +2111,7 @@ our $select_gnusocial_setup=sub {
    my @options=('GNU Social & MySQL & NGINX on 1 Server');
    my $gnusocial_setup_banner=<<'END';
 
-  
-                          https://gnu.io/social/
+                           https://gnu.io/social/
 
                         ____ _   _ _   _     ____             _       _
         ,= ,-_-. =.    / ___| \ | | | | |   / ___|  ___   ___(_) __ _| |
@@ -1922,3 +2145,4 @@ END
 };
 
 1
+ 
